@@ -103,6 +103,20 @@ func TestExpandRegexpMatchInString(t *testing.T) {
 			input:    "ref+vault://srv/foo/bar\n",
 			expected: "vault-srv-/foo/bar\n",
 		},
+		{
+			name:     "it should not match closing quotes when using query params",
+			regex:    DefaultRefRegexp,
+			only:     []string{"ref", "secretref"},
+			input:    "\"ref+awsssm://srv/foo/bar?mode=singleparam\"",
+			expected: "\"awsssm-srv-/foo/bar\"",
+		},
+		{
+			name:     "it should not match closing quotes and prevent greedy matches like it occurs in json",
+			regex:    DefaultRefRegexp,
+			only:     []string{"ref", "secretref"},
+			input:    "\"ref+awsssm://srv/foo/bar?mode=singleparam\",\n\"ref+awsssm://srv2/foo/bar?mode=singleparam\"",
+			expected: "\"awsssm-srv-/foo/bar\",\n\"awsssm-srv2-/foo/bar\"",
+		},
 		{
 			name:     "it should match greedily upto a space when using query params",
 			regex:    DefaultRefRegexp,
